@@ -18,8 +18,9 @@
 
 #include "mdaDegrade.h"
 
-#include <math.h>
-#include <float.h>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 AudioEffect *createEffectInstance(audioMasterCallback audioMaster)
 {
@@ -151,7 +152,6 @@ void mdaDegrade::getParameterName(int32_t index, char *label)
   }
 }
 
-#include <stdio.h>
 static void int2strng(int32_t value, char *string) { sprintf(string, "%d", value); }
 
 void mdaDegrade::getParameterDisplay(int32_t index, char *text)
