@@ -18,8 +18,9 @@
 
 #include "mdaDubDelay.h"
 
-#include <math.h>
-#include <float.h>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 AudioEffect *createEffectInstance(audioMasterCallback audioMaster)
 {
@@ -165,7 +166,6 @@ void mdaDubDelay::getParameterName(int32_t index, char *label)
   }
 }
 
-#include <stdio.h>
 static void int2strng(int32_t value, char *string) { sprintf(string, "%d", value); }
 static void float2strng(float value, char *string) { sprintf(string, "%.2f", value); }
 
