@@ -19,10 +19,12 @@
 #include "mdaEPianoData.h"
 #include "mdaEPiano.h"
 
+#include "lv2/atom/atom.h"
 #include "lv2/atom/util.h"
 
-#include <stdio.h>
-#include <math.h>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 //#include "AEffEditor.hpp" ////for GUI
 
