@@ -18,8 +18,9 @@
 
 #include "mdaImage.h"
 
-#include <math.h>
-#include <float.h>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 AudioEffect *createEffectInstance(audioMasterCallback audioMaster)
 {
@@ -163,7 +164,6 @@ void mdaImage::getParameterName(int32_t index, char *label)
   }
 }
 
-#include <stdio.h>
 static void int2strng(int32_t value, char *string) { sprintf(string, "%d", value); }
 
 void mdaImage::getParameterDisplay(int32_t index, char *text)
