@@ -20,9 +20,9 @@
 
 #include "mdaLeslie.h"
 
-#include <stdlib.h>
-#include <math.h>
-#include <float.h>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 AudioEffect *createEffectInstance(audioMasterCallback audioMaster)
 {
@@ -214,7 +214,6 @@ void mdaLeslie::getParameterName(int32_t index, char *label)
   }
 }
 
-#include <stdio.h>
 static void int2strng(int32_t value, char *string) { sprintf(string, "%d", value); }
 
 void mdaLeslie::getParameterDisplay(int32_t index, char *text)
