@@ -18,7 +18,9 @@
 
 #include "mdaRingMod.h"
 
-#include <math.h>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 AudioEffect *createEffectInstance(audioMasterCallback audioMaster)
 {
@@ -110,7 +112,6 @@ void mdaRingMod::getParameterName(int32_t index, char *label)
   }
 }
 
-#include <stdio.h>
 static void int2strng(int32_t value, char *string) { sprintf(string, "%d", value); }
 
 void mdaRingMod::getParameterDisplay(int32_t index, char *text)
