@@ -18,9 +18,9 @@
 
 #include "mdaShepard.h"
 
-#include <math.h>
-#include <float.h>
-#include <stdlib.h>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 AudioEffect *createEffectInstance(audioMasterCallback audioMaster)
 {
@@ -142,7 +142,6 @@ void mdaShepard::getParameterName(int32_t index, char *label)
   }
 }
 
-#include <stdio.h>
 static void int2strng(int32_t value, char *string) { sprintf(string, "%d", value); }
 
 void mdaShepard::getParameterDisplay(int32_t index, char *text)
