@@ -18,12 +18,10 @@
 
 #include "mdaTalkBox.h"
 
-#include <assert.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <float.h>
-#include <math.h>
-
+#include <cassert>
+#include <cmath>
+#include <cstdio>
+#include <cstring>
 
 AudioEffect *createEffectInstance(audioMasterCallback audioMaster)
 {
@@ -350,6 +348,8 @@ void mdaTalkBox::lpc(float *buf, float *car, int32_t n, int32_t o)
   float z[ORD_MAX], r[ORD_MAX], k[ORD_MAX], G, x;
   int32_t i, j, nn=n;
 
+  r[0] = 0.0f;
+
   for(j=0; j<=o; j++, nn--)  //buf[] is already emphasized and windowed
   {
     z[j] = r[j] = 0.0f;
